# -*- coding: utf-8 -*-

#    Copyright 2020 Fabien Bourgeois <fabien@yaltik.com>
#    Copyright 2020 Youssef El Ouahby <youssef@yaltik.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

""" GOLEM Resource holiday Management"""

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError


class GolemResourceHoliday(models.Model):
    """ GOLEM Resource Holiday Management """
    _name = 'golem.resource.holiday'
    _description = 'GOLEM Resource Holiday Managementl'
    _inherit = 'mail.thread'
    _order = 'name asc'

    name = fields.Char(compute='_compute_name', store=True)
    period_id = fields.Many2one('golem.resource.holiday.period', string='Holiday period',
                                ondelete='cascade')
    date_start = fields.Date('Holiday start')
    date_end = fields.Date('Holiday end')

    @api.depends('period_id', 'date_start', 'date_end')
    def _compute_name(self):
        """ Computes holiday name """
        for holiday in self:
            holiday.name = u'{}/{}:{}'.format(holiday.period_id.name,
                                              holiday.date_start,
                                              holiday.date_end)

    @api.constrains('date_start', 'date_end')
    def _check_date_consistency(self):
        """ Checks date consistency """
        for holiday in self:
            if holiday.date_end <= holiday.date_start:
                raise ValidationError(_('Date end should be after than '
                                        'date start'))
